@@ -1,7 +1,7 @@
 package Perinci::Sub::To::POD;
 
-our $DATE = '2016-02-26'; # DATE
-our $VERSION = '0.76'; # VERSION
+our $DATE = '2016-03-02'; # DATE
+our $VERSION = '0.77'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -239,7 +239,7 @@ sub after_gen_doc {
         } elsif ($export == 1) {
             $self->add_doc_lines(__("This function is exported by default."), "");
         } elsif ($export == -1) {
-            $self->add_doc_lines(__("This function is not exportable."), "");
+            $self->add_doc_lines(__("This function is not exported."), "");
         }
     }
 
@@ -315,7 +315,7 @@ sub after_gen_doc {
             next if 'hidden' ~~ @{ $ra->{arg}{tags} // [] };
             $self->add_doc_lines(join(
                 "",
-                "=item * B<", $name, ">",
+                "=item * B<".(($orig_args_as =~ /array/ ? '$' : '').$name).">",
                 ($ra->{arg}{req} ? '*' : ''), ' => ',
                 "I<", $ra->{human_arg}, ">",
                 (defined($ra->{human_arg_default}) ?
@@ -406,7 +406,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.76 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2016-02-26.
+This document describes version 0.77 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2016-03-02.
 
 =head1 SYNOPSIS
 
